API Version: 1.0
Library Version: 1.0
Generated by gi-docgen 2026.1
enum Frida.Exceptor
How the agent should take over exception handling in the target.
FRIDA_EXCEPTOR_FULL
Install handlers and keep the target from overriding them.
0
FRIDA_EXCEPTOR_HANDLER_ONLY
Install handlers but let the target replace them.
1
FRIDA_EXCEPTOR_OFF
Do not handle exceptions.
2
Content